@@ -136,69 +136,90 @@ class TestChannel(object):
     def test_send_and_delete_file(self, channel, random_user):
         url = "https://homepages.cae.wisc.edu/~ece533/images/lena.png"
         resp = channel.send_file(url, "lena.png", random_user)
-        assert "lena.png" in resp['file']
-        resp = channel.delete_file(resp['file'])
+        assert "lena.png" in resp["file"]
+        resp = channel.delete_file(resp["file"])
 
     def test_send_and_delete_image(self, channel, random_user):
         url = "https://homepages.cae.wisc.edu/~ece533/images/lena.png"
-        resp = channel.send_image(url, "lena.png", random_user, content_type="image/png")
-        assert "lena.png" in resp['file']
+        resp = channel.send_image(
+            url, "lena.png", random_user, content_type="image/png"
+        )
+        assert "lena.png" in resp["file"]
         # resp = channel.delete_image(resp['file'])
 
+    def test_send_image_with_bot_blocked(self, channel, random_user):
+        # following url blocks bots and we set a generic header to skip it
+        # but it can start failing again, see initial discussion here: https://github.com/GetStream/stream-chat-python/pull/30#discussion_r444209891
+        url = "https://api.twilio.com/2010-04-01/Accounts/AC3e136e1a00279f4dadcb10a9f1a1e8a3/Messages/MM547edf6f4846a30231c3033fa20f8419/Media/ME498020f8fe0b0ba2ff83ac99e4782e02"
+        resp = channel.send_image(url, "js.png", random_user, content_type="image/png")
+        assert "js.png" in resp["file"]
+
     def test_channel_hide_show(self, client, channel, random_users):
         # setup
-        channel.add_members([u['id'] for u in random_users])
+        channel.add_members([u["id"] for u in random_users])
         # verify
         response = client.query_channels({"id": channel.id})
-        assert len(response['channels']) == 1
-        response = client.query_channels({"id": channel.id}, user_id=random_users[0]['id'])
-        assert len(response['channels']) == 1
+        assert len(response["channels"]) == 1
+        response = client.query_channels(
+            {"id": channel.id}, user_id=random_users[0]["id"]
+        )
+        assert len(response["channels"]) == 1
         # hide
-        channel.hide(random_users[0]['id'])
-        response = client.query_channels({"id": channel.id}, user_id=random_users[0]['id'])
-        assert len(response['channels']) == 0
+        channel.hide(random_users[0]["id"])
+        response = client.query_channels(
+            {"id": channel.id}, user_id=random_users[0]["id"]
+        )
+        assert len(response["channels"]) == 0
         # search hidden channels
-        response = client.query_channels({"id": channel.id, "hidden": True}, user_id=random_users[0]['id'])
-        assert len(response['channels']) == 1
+        response = client.query_channels(
+            {"id": channel.id, "hidden": True}, user_id=random_users[0]["id"]
+        )
+        assert len(response["channels"]) == 1
         # unhide
-        channel.show(random_users[0]['id'])
-        response = client.query_channels({"id": channel.id}, user_id=random_users[0]['id'])
-        assert len(response['channels']) == 1
+        channel.show(random_users[0]["id"])
+        response = client.query_channels(
+            {"id": channel.id}, user_id=random_users[0]["id"]
+        )
+        assert len(response["channels"]) == 1
         # hide again
-        channel.hide(random_users[0]['id'])
-        response = client.query_channels({"id": channel.id}, user_id=random_users[0]['id'])
-        assert len(response['channels']) == 0
+        channel.hide(random_users[0]["id"])
+        response = client.query_channels(
+            {"id": channel.id}, user_id=random_users[0]["id"]
+        )
+        assert len(response["channels"]) == 0
         # send message
         channel.send_message({"text": "hi"}, random_users[1]["id"])
         # channel should be listed now
-        response = client.query_channels({"id": channel.id}, user_id=random_users[0]['id'])
-        assert len(response['channels']) == 1
+        response = client.query_channels(
+            {"id": channel.id}, user_id=random_users[0]["id"]
+        )
+        assert len(response["channels"]) == 1
 
     def test_invites(self, client, channel):
         members = ["john", "paul", "george", "pete", "ringo", "eric"]
         client.update_users([{"id": m} for m in members])
         channel = client.channel(
-            "team", "beatles-" + str(uuid.uuid4()), {
-                "members": members,
-                "invites": ["ringo", "eric"]
-            })
+            "team",
+            "beatles-" + str(uuid.uuid4()),
+            {"members": members, "invites": ["ringo", "eric"]},
+        )
         channel.create("john")
         # accept the invite when not a member
         with pytest.raises(StreamAPIException):
             channel.accept_invite("brian")
         # accept the invite when a member
         accept = channel.accept_invite("ringo")
-        for m in accept['members']:
-            if m['user_id'] == 'ringo':
-                assert m['invited'] is True
+        for m in accept["members"]:
+            if m["user_id"] == "ringo":
+                assert m["invited"] is True
                 assert "invite_accepted_at" in m
         # cannot accept again
         with pytest.raises(StreamAPIException):
             channel.accept_invite("ringo")
         reject = channel.reject_invite("eric")
-        for m in reject['members']:
-            if m['user_id'] == 'eric':
-                assert m['invited'] is True
+        for m in reject["members"]:
+            if m["user_id"] == "eric":
+                assert m["invited"] is True
                 assert "invite_rejected_at" in m
         # cannot reject again
         with pytest.raises(StreamAPIException):
